@@ -26,8 +26,7 @@ from KeywordsList import *
 from Parameters import *
 
 class PyJoke:
-    # Init parameters
-    params = Parameters()
+
 
     ###############################################
     ##    scoreJoke
@@ -174,8 +173,15 @@ class PyJoke:
     ##    Input:     String (argument)
     ##    Output:    best joke
     ###############################################
-    def __init__(self,sentence):
+    def __init__(self,change_p=False):
 
+        # Init parameters
+        self.params = Parameters()
+        if change_p:
+            self.params.change()
+
+
+    def getTheJoke(self, sentence):
         # Conversation
         if self.params.conv!=0:
             for i in range(self.params.conv):
@@ -184,12 +190,11 @@ class PyJoke:
                 answer = self.getJoke(keyw)
                 print "[PyJoke - joke      ] "+answer+"\n"
                 sentence = answer.encode('utf-8')
+
+                return "Désactivez le mode conversation"
         # Single output
         else:
             keyw = KeywordsList(sentence,self.params)
             #print len(keyw)
-            self.theJoke = self.getJoke(keyw).encode('utf-8')
+            return self.getJoke(keyw).encode('utf-8')
             #print self.getJoke(keyw).encode('utf-8')
-
-    def getTheJoke(self):
-        return self.theJoke
